markuptools.MarkupInventory
===========================

.. abjad-lineage:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory

.. autoclass:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.storage_format
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.name
   :noindex:

Methods
-------

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.append
   :noindex:

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.count
   :noindex:

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.extend
   :noindex:

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.index
   :noindex:

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.insert
   :noindex:

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.pop
   :noindex:

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.remove
   :noindex:

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.reverse
   :noindex:

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.sort
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.__add__
   :noindex:

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.__contains__
   :noindex:

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.__delitem__
   :noindex:

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.__delslice__
   :noindex:

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.__eq__
   :noindex:

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.__ge__
   :noindex:

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.__getitem__
   :noindex:

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.__getslice__
   :noindex:

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.__gt__
   :noindex:

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.__iadd__
   :noindex:

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.__imul__
   :noindex:

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.__iter__
   :noindex:

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.__le__
   :noindex:

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.__len__
   :noindex:

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.__lt__
   :noindex:

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.__mul__
   :noindex:

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.__ne__
   :noindex:

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.__repr__
   :noindex:

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.__reversed__
   :noindex:

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.__rmul__
   :noindex:

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.__setitem__
   :noindex:

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.__setslice__
   :noindex:
